Index: webrtc/modules/congestion_controller/probe_controller.cc |
diff --git a/webrtc/modules/congestion_controller/probe_controller.cc b/webrtc/modules/congestion_controller/probe_controller.cc |
index cf7f3e1b6157b28f4250e7451cc3cf630b04e09f..e91e06efd555c9f8a0e9e852ad4979ee9088e1cc 100644 |
--- a/webrtc/modules/congestion_controller/probe_controller.cc |
+++ b/webrtc/modules/congestion_controller/probe_controller.cc |
@@ -54,11 +54,13 @@ void ProbeController::SetBitrates(int min_bitrate_bps, |
} |
// Only do probing if: |
- // - we are mid-call, which we consider to be if |
- // |estimated_bitrate_bps_| != 0, and |
- // - the current bitrate is lower than the new |max_bitrate_bps|, and |
- // - we actually want to increase the |max_bitrate_bps_|. |
- if (estimated_bitrate_bps_ != 0 && estimated_bitrate_bps_ < max_bitrate_bps && |
+ // we are mid-call, which we consider to be if |
+ // exponential probing is not active and |
+ // |estimated_bitrate_bps_| is valid (> 0) and |
+ // the current bitrate is lower than the new |max_bitrate_bps|, and |
+ // we actually want to increase the |max_bitrate_bps_|. |
+ if (state_ != State::kWaitingForProbingResult && |
+ estimated_bitrate_bps_ != 0 && estimated_bitrate_bps_ < max_bitrate_bps && |
max_bitrate_bps > max_bitrate_bps_) { |
InitiateProbing({max_bitrate_bps}, kExponentialProbingDisabled); |
} |